#
# spec file for package python-markdown2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without  test
Name:           python-markdown2
Version:        2.3.7
Release:        lp151.2.3.1
Summary:        A Python implementation of Markdown
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/trentm/python-markdown2
Source:         https://files.pythonhosted.org/packages/source/m/markdown2/markdown2-%{version}.tar.gz
Patch0:         fix-build.patch
Patch1:         0001-Fix-for-issue-348-incomplete-tags-with-punctuation-a.patch
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Markdown2 is a Python implementation of Markdown.
It closely matches the behaviour of the original
Perl-implemented Markdown.pl. Markdown2 also comes with a number of
extensions (called "extras") for things like syntax coloring, tables,
header-ids.

%prep
%setup -q -n markdown2-%{version}
%patch0 -p1
%patch1 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/markdown2
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd test
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python test.py -- -knownfailure
popd

%post
%python_install_alternative markdown2

%postun
%python_uninstall_alternative markdown2

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.md CONTRIBUTORS.txt TODO.txt
%python_alternative %{_bindir}/markdown2
%{python_sitelib}/*

%changelog
* Thu May  7 2020 Petr Cervinka <petr@cervinka.net>
- Add patch to fix unsanitized input for cross-site scripting (boo#1171379)
  0001-Fix-for-issue-348-incomplete-tags-with-punctuation-a.patch
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.3.7:
  [pull #282] Add TOC depth option
  [pull #283] Fix to add TOC html to output via CLI
  [pull #284] Do not remove anchors in safe_mode
  [pull #288] fixing cuddled-lists with a single list item
  [pull #292] Fix Wrong rendering of last list element
  [pull #295] link-patterns fix
  [pull #300] Replace a deprecated method
  [pull #301] DeprecationWarning: invalid escape sequence
  [pull #302] Fix "make test" in Python 3
  [pull #303] Fix CVE-2018-5773
  [pull #306] Drop support for legacy Python versions
  [pull #307] Fix syntax highlighting test cases that depend on Pygments output
  [pull #308] Add support for Python 3.7
  [pull #304] Add Wheel package support
  [pull #312] Fix toc_depth initialization regression
  [pull #315] XSS fix
- Drop merged patch:
  * disable-failing-tests.patch
- Add patch from upstream to fix build command:
  * fix-build.patch
* Sun Jul 29 2018 jengelh@inai.de
- Ensure accuracy of description.
* Wed Jun  6 2018 petr@cervinka.net
- Update to version 2.3.5
  * [pull #238] Fenced code blocks lang with leading space
  * [pull #260] Search for items only within metadata header
  * [pull #264] highlightjs language class support
  * [pull #265] FIPS compliance
  * [pull #274] Fix for double amp replacement inside link title
- Update description from upstream
- Add pygments to BuildRequires
- Replace devel BuildRequires by base
- Apply spec-cleaner
- Add patch disable-failing-tests.patch to disable failing tests,
  upstream has no fix yet https://github.com/trentm/python-markdown2/issues/281
* Wed Aug 16 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 2.3.4
  * [pull #243] task list extra visual changes
  * [pull #245] Don't let "target-blank-lines" break footnotes
  * [pull #247] Translatable footnote titles
  * [pull #252] Add pipe escaping in table extension
- Update to version 2.3.3
  * [pull #236] Fix for safe_mode links regression
  * [pull #235] Fix for overgreedy regex in metadata
  * [pull #237] Fix for header-ids extra non-alpha character issue
- Update to version 2.3.2
  * [pull #204] toc extra Python 3 error
  * [pull #207] Performance improvements
  * [pull #210] Leading paragraph with fenced code blocks
  * [pull #212] Target blank links extra
  * [pull #215] Optional metadata fences
  * [pull #218] Github style task list
  * [pull #220] Numbering extra
  * [pull #224] Metadata in blocks
  * [pull #230] safe_mode changes
- Update to version 2.3.1
  * [pull #131] Markdown "spoiler" extra
  * [pull #170] html-classes support for table tags
  * [pull #190] "strike" extra
  * [pull #201] Allow empty table cells
* Wed Apr 29 2015 toddrme2178@gmail.com
- Initial version
